import { EventEmitter } from './events/eventEmitter';
import { IRealRendererEvents } from '../../constants/events/RealRendererEvents';
import { GraphDimensions, Color, RealRendererOptions, Stroke, RealRendererSettings, BGType, SVGSections } from '../../types/RealRendererTypes';
export * as RealRendererTypes from '../../types/RealRendererTypes';
export * from '../../constants/defaults/RealRendererDefaults';
import { undo, redo } from './undo';
import { exportData, importData } from './import-export';
import { changeBackground, normalizeBG } from './background';
import { attach, _setSVG, _setViewBox } from './svg/svg-dom';
import { scale, changeOffsets } from './svg/svg-settings';
import { _drawFunc, _draw, draw, _display, _addStroke } from './draw/draw';
import { startRender, stopRender, toggleRender, _render } from './draw/render';
/**
 * General Real Renderer with no specific purpose. Should be extended to use.
 */
export declare class RealRenderer<EventTypes extends IRealRendererEvents = IRealRendererEvents> extends EventEmitter<EventTypes> {
    svg: SVGSVGElement;
    svgSections: SVGSections;
    dimensions: GraphDimensions;
    scaleFactor: number;
    _offsetX: number;
    _offsetY: number;
    originalDimensions: GraphDimensions;
    strokes: Stroke[];
    settings: RealRendererSettings;
    _strokeIndex: number;
    bgColor: Color;
    bgType: BGType;
    drawsPerFrame: number;
    timeStep: number;
    time: number;
    _doRender: boolean;
    undo: typeof undo;
    redo: typeof redo;
    exportData: typeof exportData;
    importData: typeof importData;
    changeBackground: typeof changeBackground;
    scale: typeof scale;
    changeOffsets: typeof changeOffsets;
    attach: typeof attach;
    draw: typeof draw;
    startRender: typeof startRender;
    stopRender: typeof stopRender;
    toggleRender: typeof toggleRender;
    protected normalizeBG: typeof normalizeBG;
    protected _setSVG: typeof _setSVG;
    protected _setViewBox: typeof _setViewBox;
    protected _drawFunc: typeof _drawFunc;
    protected _draw: typeof _draw;
    protected _display: typeof _display;
    protected _addStroke: typeof _addStroke;
    protected _render: typeof _render;
    /**
     *
     * @param options
     * @param eventList
     */
    constructor(options: RealRendererOptions, eventList?: (keyof EventTypes)[]);
    /**
     * Resets the internal time counter.
     * @returns Self for chaining.
     */
    resetTime(): this;
    /**
     * Resets everything regarding the graph.
     * @returns Self for chaining.
     */
    reset(): this;
}
