"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeBG = exports.changeBackground = void 0;
var blankGraph_1 = require("../../pathMakers/blankGraph");
var clamp_1 = require("../../util/clamp");
/**
 * Changes the background of the graph.
 * @param newBG New background.
 * @returns Self for chaining.
 */
function changeBackground(newBG) {
    this.bgType = newBG;
    var newBGStrokes = blankGraph_1.getBlankGraphPaths(this.dimensions, this.bgColor, this.bgType);
    this.normalizeBG();
    this.strokes[0].forEach(function (stroke) { return stroke.delete(); });
    this.strokes[0] = newBGStrokes;
    this._display(this.strokes[0]);
    return this;
}
exports.changeBackground = changeBackground;
function normalizeBG() {
    switch (this.bgType.type) {
        case 'axes':
            this.bgType.xOffset = clamp_1.clamp(this.bgType.xOffset, 0, 100); // %age
            this.bgType.yOffset = clamp_1.clamp(this.bgType.yOffset, 0, 100); // %age
            break;
        case 'grid':
            this.bgType.xSpacing = clamp_1.clamp(this.bgType.xSpacing, 0, 100); // %age
            this.bgType.ySpacing = clamp_1.clamp(this.bgType.ySpacing, 0, 100); // %age
            if (this.bgType.xSpacing === 0)
                this.bgType.xSpacing = 1;
            if (this.bgType.ySpacing === 0)
                this.bgType.ySpacing = 1;
            break;
        case 'ruled':
            this.bgType.spacing = clamp_1.clamp(this.bgType.spacing, 0, 100);
            if (this.bgType.spacing === 0)
                this.bgType.spacing = 1;
            break;
        case 'none':
            break;
        default:
            break;
    }
}
exports.normalizeBG = normalizeBG;
