"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.importData = exports.exportData = void 0;
var _circle_1 = require("./strokeNodes/_circle");
var _path_1 = require("./strokeNodes/_path");
var _text_1 = require("./strokeNodes/_text");
var _group_1 = require("./strokeNodes/_group");
var _polygon_1 = require("./strokeNodes/_polygon");
/**
 * Export the data of the graph in a certain format that can be used to load the data later. Load using .importData().
 * @returns Data of the graph in a storable and loadable format.
 */
function exportData() {
    var strokeExport = [];
    this.strokes.forEach(function (stroke) {
        strokeExport.push(stroke.map(function (node) { return node.export(); }));
    });
    return {
        exportData: strokeExport,
        strokeIndex: this._strokeIndex,
        dimensions: this.dimensions,
        bgType: this.bgType
    };
}
exports.exportData = exportData;
/**
 * Import the data exported by .export() method.
 * @param data Data exported by .export()
 * @returns Self for chaining.
 */
function importData(data) {
    var _this = this;
    this.strokes.forEach(function (stroke) {
        stroke.forEach(function (node) { return node.delete(); });
    });
    this.svg.setAttribute('viewBox', "0 0 " + this.dimensions[0] + " " + this.dimensions[1]);
    if (data.bgType)
        this.bgType = data.bgType;
    this.strokes = [];
    data.exportData.forEach(function (strokeExport) {
        _this.strokes.push(strokeExport.map(function (strokeNodeData) {
            switch (strokeNodeData.type) {
                case 'circle':
                    var circ = new _circle_1.Circle([0, 0], 0, strokeNodeData.section ? strokeNodeData.section : 'strokes');
                    circ.import(strokeNodeData.data);
                    return circ;
                case 'path':
                    var path = new _path_1.Path('', strokeNodeData.section ? strokeNodeData.section : 'strokes');
                    path.import(strokeNodeData.data);
                    return path;
                case 'text':
                    var text = new _text_1.Text([0, 0], '', strokeNodeData.section ? strokeNodeData.section : 'strokes');
                    text.import(strokeNodeData.data);
                    return text;
                case 'group':
                    var group = new _group_1.GroupNode(strokeNodeData.section ? strokeNodeData.section : 'strokes', []);
                    group.import(strokeNodeData.data);
                    return group;
                case 'polygon':
                    var polygon = new _polygon_1.Polygon([], strokeNodeData.section ? strokeNodeData.section : 'strokes');
                    polygon.import(strokeNodeData.data);
                    return polygon;
            }
        }));
    });
    this._strokeIndex = data.strokeIndex;
    for (var i = 0; i <= this._strokeIndex; i++) {
        this._display(this.strokes[i]);
    }
    this.emit('import', {
        import: data
    });
    return this;
}
exports.importData = importData;
