"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.attach = exports._setViewBox = exports._setSVG = void 0;
var blankGraph_1 = require("../../../pathMakers/blankGraph");
function _setSVG() {
    if (this.svg === undefined) {
        throw 'No SVG Element Found';
    }
    this._setViewBox(this.dimensions, this._offsetX, this._offsetY);
    this.svg.setAttribute('preserveAspectRatio', 'none');
    this.svgSections = {
        bg: document.createElementNS('http://www.w3.org/2000/svg', 'g'),
        strokes: document.createElementNS('http://www.w3.org/2000/svg', 'g'),
        overlay: document.createElementNS('http://www.w3.org/2000/svg', 'g')
    };
    this.svg.appendChild(this.svgSections.bg);
    this.svg.appendChild(this.svgSections.strokes);
    this.svg.appendChild(this.svgSections.overlay);
    this._addStroke(blankGraph_1.getBlankGraphPaths(this.dimensions, this.bgColor, this.bgType));
    this._display(this.strokes[this._strokeIndex]);
    this._doRender = false;
}
exports._setSVG = _setSVG;
function _setViewBox(dimensions, xOffset, yOffset) {
    this.svg.setAttribute('viewBox', xOffset + " " + yOffset + " " + dimensions[0] + " " + dimensions[1]);
}
exports._setViewBox = _setViewBox;
/**
   * Attaches to a DOM SVG element to render to.
   * @param svg The SVG element to attach.
   * @param dimensions Dimensions of the graph.
   * @returns Self for chaining.
   */
function attach(svg, dimensions) {
    this.dimensions = dimensions;
    this.originalDimensions = [
        dimensions[0],
        dimensions[1]
    ];
    this.svg = svg;
    this._setSVG();
    return this;
}
exports.attach = attach;
