"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.changeOffsets = exports.scale = void 0;
var clamp_1 = require("../../../util/clamp");
/**
 * Scale/zoom the graph.
 * @param scaleFactor Factor to scale the graph by. Larger number zooms in.
 * @returns Self for chaining.
 */
function scale(scaleFactor) {
    var oldScaleFactor = this.scaleFactor;
    this.scaleFactor = scaleFactor;
    this.dimensions[0] = this.originalDimensions[0] / scaleFactor;
    this.dimensions[1] = this.originalDimensions[1] / scaleFactor;
    // To clamp the offsets as well
    this.changeOffsets(this._offsetX, this._offsetY);
    this.emit('change-scale', {
        oldScaleFactor: oldScaleFactor,
        newScaleFactor: this.scaleFactor
    });
    return this;
}
exports.scale = scale;
/**
 * Change the offsets of the graph (for panning)
 * @param xOffset Offset in the x-direction.
 * @param yOffset Offset in the y-direction.
 * @returns Self for chaining.
 */
function changeOffsets(xOffset, yOffset) {
    var oldOffsets = {
        x: this._offsetX,
        y: this._offsetY
    };
    this._offsetX = clamp_1.clamp(xOffset, 0, this.originalDimensions[0] - this.dimensions[0]);
    this._offsetY = clamp_1.clamp(yOffset, 0, this.originalDimensions[1] - this.dimensions[1]);
    this._setViewBox(this.dimensions, this._offsetX, this._offsetY);
    this.emit('change-offsets', {
        oldOffsets: oldOffsets,
        newOffsets: {
            x: this._offsetX,
            y: this._offsetY
        }
    });
    return this;
}
exports.changeOffsets = changeOffsets;
